@@ -7,7 +7,7 @@
 """
 Python QtScreenCaster.
 """
-from .QtScreenCast import ScreenCastToolButton
+from .QtScreenCast import *
 
 __version__ = "0.0.0"
-__version__='0.1.10'
+__version__='0.1.13'
